package StewartPlatform "Package containing model of six-degree-of-freedom Stewart platform"
  package Components "Package containing components for Stewart platform model"
    model Platform "Hexagonal six-degree-of-freedom surface of Stewart platform"
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation leg1Attachment(r = legPlatformRelativePositions[1], animation = true) annotation(Placement(visible = true, transformation(origin = {60.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation leg2Attachment(r = legPlatformRelativePositions[2], animation = true) annotation(Placement(visible = true, transformation(origin = {10.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation leg3Attachment(r = legPlatformRelativePositions[3], animation = true) annotation(Placement(visible = true, transformation(origin = {-30.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation leg4Attachment(r = legPlatformRelativePositions[4], animation = true) annotation(Placement(visible = true, transformation(origin = {-30.0, -20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation leg5Attachment(r = legPlatformRelativePositions[5], animation = true) annotation(Placement(visible = true, transformation(origin = {10.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.MultiBody.Parts.FixedTranslation leg6Attachment(r = legPlatformRelativePositions[6], animation = true) annotation(Placement(visible = true, transformation(origin = {60.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_b[6] annotation(Placement(visible = true, transformation(origin = {148.1667, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {99.7755, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.BodyShape platform(I_11 = inertiaTensor[1, 1], I_22 = inertiaTensor[2, 2], I_33 = inertiaTensor[3, 3], m = mass, shapeType = "modelica://StewartPlatform/DocumentationFiles/Platform.obj", r_0.start = {0, platformHeight, 0}, r_0.fixed = true, I_21 = inertiaTensor[2, 1], I_31 = inertiaTensor[3, 1], I_32 = inertiaTensor[3, 2]) annotation(Placement(visible = true, transformation(origin = {-130.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      parameter Modelica.SIunits.Length platformHeight = 0.15;
      parameter Real legPlatformRelativePositions[6, 3] = {{0.0707106781186548, 0, 0.0707106781186548}, {0.0258819045102521, 0, 0.0965925826289068}, {-0.0965925826289068, 0, 0.0258819045102521}, {-0.0965925826289068, 0, -0.0258819045102521}, {0.0258819045102521, 0, -0.0965925826289068}, {0.0707106781186548, 0, -0.0707106781186548}};
      parameter Real inertiaTensor[3, 3] = {{0.00344801, 0, 0}, {0, 0.00686603, 0}, {0, 0, 0.00344801}};
      parameter Real mass = 1.8;
    equation
      connect(leg6Attachment.frame_b, frame_b[6]) annotation(Line(visible = true, origin = {119.542, -40}, points = {{-49.542, -40}, {10.458, -40}, {10.458, 40}, {28.625, 40}}, color = {95, 95, 95}));
      connect(leg1Attachment.frame_b, frame_b[1]) annotation(Line(visible = true, origin = {94.542, 40}, points = {{-24.542, 40}, {35.458, 40}, {35.458, -40}, {53.625, -40}}, color = {95, 95, 95}));
      connect(leg5Attachment.frame_b, frame_b[5]) annotation(Line(visible = true, origin = {81.361, -46.667}, points = {{-61.361, -33.333}, {-51.361, -33.333}, {-51.361, -13.333}, {48.639, -13.333}, {48.639, 46.667}, {66.806, 46.667}}, color = {95, 95, 95}));
      connect(leg4Attachment.frame_b, frame_b[4]) annotation(Line(visible = true, origin = {77.042, -10}, points = {{-97.042, -10}, {52.958, -10}, {52.958, 10}, {71.125, 10}}, color = {95, 95, 95}));
      connect(leg3Attachment.frame_b, frame_b[3]) annotation(Line(visible = true, origin = {72.042, 10}, points = {{-92.042, 10}, {57.958, 10}, {57.958, -10}, {76.125, -10}}, color = {95, 95, 95}));
      connect(leg2Attachment.frame_b, frame_b[2]) annotation(Line(visible = true, origin = {81.361, 46.667}, points = {{-61.361, 33.333}, {-51.361, 33.333}, {-51.361, 13.333}, {48.639, 13.333}, {48.639, -46.667}, {66.806, -46.667}}, color = {95, 95, 95}));
      connect(leg6Attachment.frame_a, platform.frame_a) annotation(Line(visible = true, origin = {-35, -60}, points = {{85, -20}, {75, -20}, {75, -40}, {-75, -40}, {-75, 60}, {-85, 60}}, color = {95, 95, 95}));
      connect(leg5Attachment.frame_a, platform.frame_a) annotation(Line(visible = true, origin = {-85, -40}, points = {{85, -40}, {-25, -40}, {-25, 40}, {-35, 40}}, color = {95, 95, 95}));
      connect(leg4Attachment.frame_a, platform.frame_a) annotation(Line(visible = true, origin = {-95, -10}, points = {{55, -10}, {-15, -10}, {-15, 10}, {-25, 10}}, color = {95, 95, 95}));
      connect(leg3Attachment.frame_a, platform.frame_a) annotation(Line(visible = true, origin = {-95, 10}, points = {{55, 10}, {-15, 10}, {-15, -10}, {-25, -10}}, color = {95, 95, 95}));
      connect(leg2Attachment.frame_a, platform.frame_a) annotation(Line(visible = true, origin = {-85, 40}, points = {{85, 40}, {-25, 40}, {-25, -40}, {-35, -40}}, color = {95, 95, 95}));
      connect(leg1Attachment.frame_a, platform.frame_a) annotation(Line(visible = true, origin = {-35, 60}, points = {{85, 20}, {75, 20}, {75, 40}, {-75, 40}, {-75, -60}, {-85, -60}}, color = {95, 95, 95}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Platform -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Platform</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models the hexagonal six-degree-of-freedom surface of a Stewart platform.
</p><p class=\"\">
View the <a href=\"modelica://StewartPlatform.Components.Platform#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Platform --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Bitmap(visible = true, fileName = "modelica://StewartPlatform/DocumentationFiles/Platform.png", imageSource = "", extent = {{-100, -100}, {100, 100}}), Text(visible = not useAxisFlange, origin = {0, 15}, textColor = {0, 0, 255}, extent = {{-150, 55}, {150, 115}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end Platform;

    model Base "Hexagonal fixed base of Stewart platform"
      Modelica.Mechanics.MultiBody.Parts.Fixed leg1Mount(r = legBasePoints[1], animation = false) annotation(Placement(visible = true, transformation(origin = {60.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.Fixed leg2Mount(r = legBasePoints[2], animation = false) annotation(Placement(visible = true, transformation(origin = {-20.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.Fixed leg3Mount(r = legBasePoints[3], animation = false) annotation(Placement(visible = true, transformation(origin = {-80.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.Fixed leg4Mount(r = legBasePoints[4], animation = false) annotation(Placement(visible = true, transformation(origin = {-80.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.Fixed leg5Mount(r = legBasePoints[5], animation = false) annotation(Placement(visible = true, transformation(origin = {-20.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.Fixed leg6Mount(r = legBasePoints[6], animation = false) annotation(Placement(visible = true, transformation(origin = {60.0, -20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.Fixed origin(animation = false) annotation(Placement(visible = true, transformation(origin = {-30.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_b[6] annotation(Placement(visible = true, transformation(origin = {147.8882, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {99.588, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Parts.BodyShape base(animation = true, animateSphere = false, shapeType = "modelica://StewartPlatform/DocumentationFiles/Base.obj") annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Real legBasePoints[6, 3] = {{0.14488887394336, 0, 0.0388228567653781}, {-0.0388228567653781, 0, 0.14488887394336}, {-0.106066017177982, 0, 0.106066017177982}, {-0.106066017177982, 0, -0.106066017177982}, {-0.0388228567653781, 0, -0.14488887394336}, {0.14488887394336, 0, -0.0388228567653781}};
    equation
      connect(leg6Mount.frame_b, frame_b[6]) annotation(Line(visible = true, origin = {119.472, -10}, points = {{-49.472, -10}, {10.528, -10}, {10.528, 10}, {28.416, 10}}, color = {95, 95, 95}));
      connect(leg5Mount.frame_b, frame_b[5]) annotation(Line(visible = true, origin = {99.472, -40}, points = {{-109.472, -40}, {30.528, -40}, {30.528, 40}, {48.416, 40}}, color = {95, 95, 95}));
      connect(leg4Mount.frame_b, frame_b[4]) annotation(Line(visible = true, origin = {36.315, -46.667}, points = {{-106.315, -33.333}, {-96.315, -33.333}, {-96.315, -13.333}, {93.685, -13.333}, {93.685, 46.667}, {111.574, 46.667}}, color = {95, 95, 95}));
      connect(leg3Mount.frame_b, frame_b[3]) annotation(Line(visible = true, origin = {36.315, 46.667}, points = {{-106.315, 33.333}, {-96.315, 33.333}, {-96.315, 13.333}, {93.685, 13.333}, {93.685, -46.667}, {111.574, -46.667}}, color = {95, 95, 95}));
      connect(leg2Mount.frame_b, frame_b[2]) annotation(Line(visible = true, origin = {99.472, 40}, points = {{-109.472, 40}, {30.528, 40}, {30.528, -40}, {48.416, -40}}, color = {95, 95, 95}));
      connect(leg1Mount.frame_b, frame_b[1]) annotation(Line(visible = true, origin = {94.472, 10}, points = {{-24.472, 10}, {-14.472, 10}, {-14.472, -10}, {53.416, -10}}, color = {95, 95, 95}));
      connect(origin.frame_b, base.frame_a) annotation(Line(visible = true, origin = {-15, 0}, points = {{-5, 0}, {5, 0}}, color = {95, 95, 95}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Base -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Base</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models the hexagonal fixed base of a Stewart platform.
</p><p class=\"\">
View the <a href=\"modelica://StewartPlatform.Components.Base#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Base --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Bitmap(visible = true, fileName = "modelica://StewartPlatform/DocumentationFiles/Base.png", imageSource = "", extent = {{-100, -100}, {100, 100}}), Text(visible = not useAxisFlange, origin = {0, 15}, textColor = {0, 0, 255}, extent = {{-150, 55}, {150, 115}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end Base;

    model Legs "Set of six actuated six-degree-of-freedom legs"
      StewartPlatform.Components.SixDOFLeg leg1(stateSelect = StateSelect.always, initialLength = initialLengths[1], legDirection = legDirections[1], initialLengthFixed = initialLengthsFixed) annotation(Placement(visible = true, transformation(origin = {60.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      StewartPlatform.Components.SixDOFLeg leg2(initialLength = initialLengths[2], legDirection = legDirections[2], initialLengthFixed = initialLengthsFixed) annotation(Placement(visible = true, transformation(origin = {60.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      StewartPlatform.Components.SixDOFLeg leg3(initialLength = initialLengths[3], legDirection = legDirections[3], initialLengthFixed = initialLengthsFixed) annotation(Placement(visible = true, transformation(origin = {60.0, 10.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      StewartPlatform.Components.SixDOFLeg leg4(initialLength = initialLengths[4], legDirection = legDirections[4], initialLengthFixed = initialLengthsFixed) annotation(Placement(visible = true, transformation(origin = {60.0, -20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      StewartPlatform.Components.SixDOFLeg leg5(initialLength = initialLengths[5], legDirection = legDirections[5], initialLengthFixed = initialLengthsFixed) annotation(Placement(visible = true, transformation(origin = {60.0, -50.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      StewartPlatform.Components.SixDOFLeg leg6(initialLength = initialLengths[6], legDirection = legDirections[6], initialLengthFixed = initialLengthsFixed) annotation(Placement(visible = true, transformation(origin = {60.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput desiredLegLengths[6] annotation(Placement(visible = true, transformation(origin = {0.0, 110.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90), iconTransformation(origin = {0.0, 120.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = -90)));
      Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_b[6] annotation(Placement(visible = true, transformation(origin = {148.4312, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {99.9537, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a[6] annotation(Placement(visible = true, transformation(origin = {-148.1667, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {-99.7755, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      parameter Modelica.SIunits.Length initialLengths[6] = {0.170350338674353, 0.170350338674353, 0.170350338674353, 0.170350338674353, 0.170350338674353, 0.170350338674353};
      parameter Real legDirections[6, 3] = {{-0.435444956563936, 0.880538313966868, 0.187189656336606}, {0.379833475995148, 0.880538313966868, -0.283511566165877}, {0.0556114805687882, 0.880538313966868, -0.470701222502483}, {0.0556114805687882, 0.880538313966868, 0.470701222502483}, {0.379833475995148, 0.880538313966868, 0.283511566165877}, {-0.435444956563936, 0.880538313966868, -0.187189656336606}};
      parameter Boolean initialLengthsFixed = false;
    equation
      connect(leg2.desiredLegLength, desiredLegLengths[2]) annotation(Line(visible = true, origin = {30, 69.995}, points = {{30, -20.016}, {30, -9.995}, {-30, -9.995}, {-30, 40.005}}, color = {0, 36, 164}));
      connect(leg1.desiredLegLength, desiredLegLengths[1]) annotation(Line(visible = true, origin = {50, 91.174}, points = {{10, -11.196}, {10, -1.175}, {-50, -1.175}, {-50, 18.826}}, color = {0, 36, 164}));
      connect(leg3.desiredLegLength, desiredLegLengths[3]) annotation(Line(visible = true, origin = {10, 47.495}, points = {{50, -27.516}, {50, -17.495}, {-10, -17.495}, {-10, 62.505}}, color = {0, 36, 164}));
      connect(leg6.desiredLegLength, desiredLegLengths[6]) annotation(Line(visible = true, origin = {-50, -20.005}, points = {{110, -50.016}, {110, -39.995}, {50, -39.995}, {50, 130.005}}, color = {0, 36, 164}));
      connect(leg5.desiredLegLength, desiredLegLengths[5]) annotation(Line(visible = true, origin = {-30, 2.495}, points = {{90, -42.516}, {90, -32.495}, {30, -32.495}, {30, 107.505}}, color = {0, 36, 164}));
      connect(leg4.desiredLegLength, desiredLegLengths[4]) annotation(Line(visible = true, origin = {-10, 24.995}, points = {{70, -35.016}, {70, -24.995}, {10, -24.995}, {10, 85.005}}, color = {0, 36, 164}));
      connect(leg6.frame_a, frame_a[6]) annotation(Line(visible = true, origin = {-129.541, -40}, points = {{179.545, -40}, {-0.46, -40}, {-0.46, 40}, {-18.626, 40}}, color = {95, 95, 95}));
      connect(leg6.frame_b, frame_b[6]) annotation(Line(visible = true, origin = {74.607, -40}, points = {{-4.611, -40}, {45.393, -40}, {45.393, 40}, {73.825, 40}}, color = {95, 95, 95}));
      connect(leg5.frame_a, frame_a[5]) annotation(Line(visible = true, origin = {-119.54, -25}, points = {{169.545, -25}, {-10.46, -25}, {-10.46, 25}, {-28.626, 25}}, color = {95, 95, 95}));
      connect(leg5.frame_b, frame_b[5]) annotation(Line(visible = true, origin = {84.607, -25}, points = {{-14.611, -25}, {35.393, -25}, {35.393, 25}, {63.825, 25}}, color = {95, 95, 95}));
      connect(leg4.frame_a, frame_a[4]) annotation(Line(visible = true, origin = {-109.54, -10}, points = {{159.545, -10}, {-20.459, -10}, {-20.459, 10}, {-38.626, 10}}, color = {95, 95, 95}));
      connect(leg4.frame_b, frame_b[4]) annotation(Line(visible = true, origin = {94.607, -10}, points = {{-24.611, -10}, {25.393, -10}, {25.393, 10}, {53.825, 10}}, color = {95, 95, 95}));
      connect(leg3.frame_a, frame_a[3]) annotation(Line(visible = true, origin = {-99.54, 5}, points = {{149.545, 5}, {-30.459, 5}, {-30.459, -5}, {-48.626, -5}}, color = {95, 95, 95}));
      connect(leg3.frame_b, frame_b[3]) annotation(Line(visible = true, origin = {104.607, 5}, points = {{-34.611, 5}, {15.393, 5}, {15.393, -5}, {43.825, -5}}, color = {95, 95, 95}));
      connect(leg1.frame_a, frame_a[1]) annotation(Line(visible = true, origin = {-79.54, 35}, points = {{129.545, 35}, {-50.459, 35}, {-50.459, -35}, {-68.626, -35}}, color = {95, 95, 95}));
      connect(leg1.frame_b, frame_b[1]) annotation(Line(visible = true, origin = {124.607, 35}, points = {{-54.611, 35}, {-4.607, 35}, {-4.607, -35}, {23.824, -35}}, color = {95, 95, 95}));
      connect(leg2.frame_b, frame_b[2]) annotation(Line(visible = true, origin = {114.607, 20}, points = {{-44.611, 20}, {5.393, 20}, {5.393, -20}, {33.825, -20}}, color = {95, 95, 95}));
      connect(leg2.frame_a, frame_a[2]) annotation(Line(visible = true, origin = {-89.54, 20}, points = {{139.545, 20}, {-40.459, 20}, {-40.459, -20}, {-58.626, -20}}, color = {95, 95, 95}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Legs -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Legs</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models a set of six six-degree-of-freedom legs with controlled lengths determined by an array of six control signals.
</p><p class=\"\">
View the <a href=\"modelica://StewartPlatform.Components.Legs#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Legs --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, origin = {-8.5714, -10.0}, lineColor = {0, 0, 255}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-71.4286, 40.0}, {-21.4286, 50.0}}), Rectangle(visible = true, origin = {-4.6154, 4.0}, lineColor = {0, 0, 255}, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-25.3846, -24.0}, {84.6154, 16.0}}), Rectangle(visible = true, origin = {-4.6154, 0.0}, lineColor = {0, 0, 255}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-25.3846, 20.0}, {84.6154, 30.0}}), Line(visible = true, points = {{-30.0, -38.3646}, {-30.0, 40.0}}), Text(visible = not useAxisFlange, origin = {0.0, -15.0}, lineColor = {0, 0, 255}, extent = {{-150.0, 55.0}, {150.0, 115.0}}, textString = "%name", fontName = "Arial"), Rectangle(visible = true, origin = {-8.5714, -1.5385}, lineColor = {0, 0, 255}, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-71.4286, -38.4615}, {-21.4286, 31.5385}}), Ellipse(visible = true, origin = {-80.0, 0.0}, fillColor = {86, 86, 86}, fillPattern = FillPattern.Solid, extent = {{-20.0, -20.0}, {20.0, 20.0}}), Polygon(visible = true, lineColor = {0, 127, 0}, fillColor = {215, 215, 215}, fillPattern = FillPattern.Solid, points = {{-90.0, 0.0}, {-60.0, 30.0}, {-60.0, 10.0}, {-10.0, 10.0}, {-10.0, -10.0}, {-60.0, -10.0}, {-60.0, -30.0}, {-90.0, 0.0}}), Ellipse(visible = true, origin = {80.0, 0.0}, fillColor = {86, 86, 86}, fillPattern = FillPattern.Solid, extent = {{-20.0, -20.0}, {20.0, 20.0}}), Polygon(visible = true, lineColor = {0, 127, 0}, fillColor = {215, 215, 215}, fillPattern = FillPattern.Solid, points = {{90.0, 0.0}, {60.0, -30.0}, {60.0, -10.0}, {10.0, -10.0}, {10.0, 10.0}, {60.0, 10.0}, {60.0, 31.0}, {90.0, 0.0}}), Text(visible = true, origin = {-6.0, 3.0}, lineColor = {128, 128, 128}, extent = {{60.0, -13.0}, {96.0, 12.0}}, textString = "b", fontName = "Arial"), Text(visible = true, origin = {5.0, 1.3708}, lineColor = {128, 128, 128}, extent = {{-95.0, -9.0}, {-60.0, 13.0}}, textString = "a", fontName = "Arial"), Text(visible = true, origin = {0.0, -45.0}, fillPattern = FillPattern.Solid, extent = {{-33.3333, -25.0}, {33.3333, 25.0}}, textString = "x6", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end Legs;

    model LegOffsets "Block adding fixed offsets to control signals for lengths of six legs"
      Modelica.Blocks.Interfaces.RealInput desiredLegLengths[6] annotation(Placement(visible = true, transformation(origin = {-150.0, 0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0), iconTransformation(origin = {-120.0, 0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput offsetLegLengths[6] annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {110.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Modelica.SIunits.Length leg1Offset = 0;
      parameter Modelica.SIunits.Length leg2Offset = 0;
      parameter Modelica.SIunits.Length leg3Offset = 0;
      parameter Modelica.SIunits.Length leg4Offset = 0;
      parameter Modelica.SIunits.Length leg5Offset = 0;
      parameter Modelica.SIunits.Length leg6Offset = 0;
      Modelica.Blocks.Math.Add add1 annotation(Placement(visible = true, transformation(origin = {-0.0, 75.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant offset1(k = leg1Offset) annotation(Placement(visible = true, transformation(origin = {-50.0, 85.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant offset2(k = leg2Offset) annotation(Placement(visible = true, transformation(origin = {-50.0, 55.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Math.Add add2 annotation(Placement(visible = true, transformation(origin = {-0.0, 45.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Math.Add add3 annotation(Placement(visible = true, transformation(origin = {-0.0, 15.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant offset3(k = leg3Offset) annotation(Placement(visible = true, transformation(origin = {-50.0, 25.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant offset4(k = leg4Offset) annotation(Placement(visible = true, transformation(origin = {-50.0, -5.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Math.Add add4 annotation(Placement(visible = true, transformation(origin = {-0.0, -15.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Math.Add add5 annotation(Placement(visible = true, transformation(origin = {-0.0, -45.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant offset5(k = leg5Offset) annotation(Placement(visible = true, transformation(origin = {-50.0, -35.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant offset6(k = leg6Offset) annotation(Placement(visible = true, transformation(origin = {-50.0, -65.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Math.Add add6 annotation(Placement(visible = true, transformation(origin = {0.0, -75.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(desiredLegLengths[1], add1.u2) annotation(Line(visible = true, origin = {-90.5, 34.5}, points = {{-59.5, -34.5}, {-9.5, -34.5}, {-9.5, 34.5}, {78.5, 34.5}}, color = {0, 36, 164}));
      connect(desiredLegLengths[2], add2.u2) annotation(Line(visible = true, origin = {-90.5, 19.5}, points = {{-59.5, -19.5}, {-9.5, -19.5}, {-9.5, 19.5}, {78.5, 19.5}}, color = {0, 36, 164}));
      connect(desiredLegLengths[3], add3.u2) annotation(Line(visible = true, origin = {-90.5, 4.5}, points = {{-59.5, -4.5}, {-9.5, -4.5}, {-9.5, 4.5}, {78.5, 4.5}}, color = {0, 36, 164}));
      connect(desiredLegLengths[4], add4.u2) annotation(Line(visible = true, origin = {-90.5, -10.5}, points = {{-59.5, 10.5}, {-9.5, 10.5}, {-9.5, -10.5}, {78.5, -10.5}}, color = {0, 36, 164}));
      connect(desiredLegLengths[5], add5.u2) annotation(Line(visible = true, origin = {-90.5, -25.5}, points = {{-59.5, 25.5}, {-9.5, 25.5}, {-9.5, -25.5}, {78.5, -25.5}}, color = {0, 36, 164}));
      connect(desiredLegLengths[6], add6.u2) annotation(Line(visible = true, origin = {-90.5, -40.5}, points = {{-59.5, 40.5}, {-9.5, 40.5}, {-9.5, -40.5}, {78.5, -40.5}}, color = {0, 36, 164}));
      connect(add1.y, offsetLegLengths[1]) annotation(Line(visible = true, origin = {90.25, 37.5}, points = {{-79.25, 37.5}, {9.75, 37.5}, {9.75, -37.5}, {59.75, -37.5}}, color = {1, 37, 163}));
      connect(add2.y, offsetLegLengths[2]) annotation(Line(visible = true, origin = {90.25, 22.5}, points = {{-79.25, 22.5}, {9.75, 22.5}, {9.75, -22.5}, {59.75, -22.5}}, color = {1, 37, 163}));
      connect(add3.y, offsetLegLengths[3]) annotation(Line(visible = true, origin = {90.25, 7.5}, points = {{-79.25, 7.5}, {9.75, 7.5}, {9.75, -7.5}, {59.75, -7.5}}, color = {1, 37, 163}));
      connect(add4.y, offsetLegLengths[4]) annotation(Line(visible = true, origin = {90.25, -7.5}, points = {{-79.25, -7.5}, {9.75, -7.5}, {9.75, 7.5}, {59.75, 7.5}}, color = {1, 37, 163}));
      connect(add5.y, offsetLegLengths[5]) annotation(Line(visible = true, origin = {90.25, -22.5}, points = {{-79.25, -22.5}, {9.75, -22.5}, {9.75, 22.5}, {59.75, 22.5}}, color = {1, 37, 163}));
      connect(add6.y, offsetLegLengths[6]) annotation(Line(visible = true, origin = {90.25, -37.5}, points = {{-79.25, -37.5}, {9.75, -37.5}, {9.75, 37.5}, {59.75, 37.5}}, color = {1, 37, 163}));
      connect(offset6.y, add6.u1) annotation(Line(visible = true, origin = {-20.25, -67}, points = {{-18.75, 2}, {5.25, 2}, {5.25, -2}, {8.25, -2}}, color = {1, 37, 163}));
      connect(offset5.y, add5.u1) annotation(Line(visible = true, origin = {-20.25, -37}, points = {{-18.75, 2}, {5.25, 2}, {5.25, -2}, {8.25, -2}}, color = {1, 37, 163}));
      connect(offset4.y, add4.u1) annotation(Line(visible = true, origin = {-20.25, -7}, points = {{-18.75, 2}, {5.25, 2}, {5.25, -2}, {8.25, -2}}, color = {1, 37, 163}));
      connect(offset3.y, add3.u1) annotation(Line(visible = true, origin = {-20.25, 23}, points = {{-18.75, 2}, {5.25, 2}, {5.25, -2}, {8.25, -2}}, color = {1, 37, 163}));
      connect(offset2.y, add2.u1) annotation(Line(visible = true, origin = {-20.25, 53}, points = {{-18.75, 2}, {5.25, 2}, {5.25, -2}, {8.25, -2}}, color = {1, 37, 163}));
      connect(offset1.y, add1.u1) annotation(Line(visible = true, origin = {-20.25, 83}, points = {{-18.75, 2}, {5.25, 2}, {5.25, -2}, {8.25, -2}}, color = {1, 37, 163}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART LegOffsets -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>LegOffsets</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models systematic errors in the lengths of the legs of a Stewart platform by adding a fixed offset to the control signal of each leg.
</p><p class=\"\">
View the <a href=\"modelica://StewartPlatform.Components.LegOffsets#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND LegOffsets --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Line(visible = true, origin = {0.0, 80.0}, points = {{70.0, 0.0}, {-70.0, 0.0}}, color = {0, 0, 255}), Line(visible = true, origin = {0.0, -80.0}, points = {{70.0, 0.0}, {-70.0, 0.0}}, color = {0, 0, 255}), Line(visible = true, points = {{0.0, 80.0}, {0.0, -80.0}}), Line(visible = true, points = {{90.0, 0.0}, {-90.0, 0.0}}), Line(visible = true, origin = {-16.1216, 40.0}, points = {{86.1216, 0.0}, {-32.2431, 0.0}, {-53.8784, 0.0}}, thickness = 1.5), Line(visible = true, origin = {-36.6667, 16.6667}, points = {{-3.3333, 23.3333}, {-3.3333, -16.6667}, {6.6667, -6.6667}}), Line(visible = true, origin = {-45.0, 5.0}, points = {{5.0, -5.0}, {-5.0, 5.0}}), Line(visible = true, origin = {-40.0, 33.3333}, points = {{-10.0, -3.3333}, {0.0, 6.6667}, {10.0, -3.3333}}), Text(visible = not useAxisFlange, origin = {0.0, 45.0}, lineColor = {0, 0, 255}, extent = {{-150.0, 55.0}, {150.0, 115.0}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end LegOffsets;

    model LinearActuator "Idealized linear actuator with proportional controller"
      Modelica.Mechanics.MultiBody.Joints.Prismatic prismatic(s.start = initialLength, s.fixed = initialLengthFixed, useAxisFlange = true, stateSelect = stateSelect, n = legDirection, boxColor = Modelica.Mechanics.MultiBody.Types.Defaults.RodColor) annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a annotation(Placement(visible = true, transformation(origin = {-150.0, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {-101.0101, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sources.Force2 controlForce annotation(Placement(visible = true, transformation(origin = {0.0, -40.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput realInput1 annotation(Placement(visible = true, transformation(origin = {-0.0, 120.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = -90), iconTransformation(origin = {0.0, 100.7937}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = -90)));
      parameter Modelica.SIunits.Length initialLength = 1;
      Modelica.Mechanics.Translational.Sensors.RelPositionSensor relPositionSensor annotation(Placement(visible = true, transformation(origin = {0.0, 30.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      parameter Modelica.SIunits.Force maxForce = 500;
      Modelica.Blocks.Continuous.LimPID controller(yMax = maxForce, k = maxForce / 0.02, controllerType = Modelica.Blocks.Types.SimpleController.P) annotation(Placement(visible = true, transformation(origin = {20.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Damper damper(d = maxForce / maxSpeed) annotation(Placement(visible = true, transformation(origin = {0.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Modelica.SIunits.Velocity maxSpeed = 0.2;
      parameter StateSelect stateSelect = StateSelect.prefer;
      Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_b annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {101.0101, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      parameter Boolean initialLengthFixed = true;
      parameter Real legDirection[3] = {0, 1, 0};
    equation
      connect(controller.y, controlForce.f) annotation(Line(visible = true, origin = {22.2, -0.8}, points = {{8.8, 70.8}, {17.8, 70.8}, {17.8, -49.2}, {-22.2, -49.2}, {-22.2, -43.2}}, color = {1, 37, 163}));
      connect(realInput1, controller.u_s) annotation(Line(visible = true, origin = {2.667, 86.667}, points = {{-2.667, 33.333}, {-2.667, -16.667}, {5.333, -16.667}}, color = {0, 36, 164}));
      connect(relPositionSensor.s_rel, controller.u_m) annotation(Line(visible = true, origin = {10, 52.25}, points = {{-10, -11.25}, {-10, 2.75}, {10, 2.75}, {10, 5.75}}, color = {1, 37, 163}));
      connect(controlForce.flange_a, prismatic.support) annotation(Line(visible = true, origin = {-11.6, -10.8}, points = {{1.6, -29.2}, {-8.4, -29.2}, {-8.4, 20.8}, {7.6, 20.8}, {7.6, 16.8}}, color = {0, 127, 0}));
      connect(controlForce.flange_b, prismatic.axis) annotation(Line(visible = true, origin = {13.2, -10.8}, points = {{-3.2, -29.2}, {6.8, -29.2}, {6.8, 20.8}, {-5.2, 20.8}, {-5.2, 16.8}}, color = {0, 127, 0}));
      connect(damper.flange_b, controlForce.flange_b) annotation(Line(visible = true, origin = {15, -55}, points = {{-5, -15}, {5, -15}, {5, 15}, {-5, 15}}, color = {0, 127, 0}));
      connect(controlForce.flange_a, damper.flange_a) annotation(Line(visible = true, origin = {-15, -55}, points = {{5, 15}, {-5, 15}, {-5, -15}, {5, -15}}, color = {0, 127, 0}));
      connect(prismatic.frame_b, frame_b) annotation(Line(visible = true, origin = {80, 0}, points = {{-70, 0}, {70, 0}}, color = {95, 95, 95}));
      connect(prismatic.frame_a, frame_a) annotation(Line(visible = true, origin = {-80, 0}, points = {{70, 0}, {-70, 0}}, color = {95, 95, 95}));
      connect(relPositionSensor.flange_b, prismatic.axis) annotation(Line(visible = true, origin = {13.2, 17.2}, points = {{-3.2, 12.8}, {6.8, 12.8}, {6.8, -7.2}, {-5.2, -7.2}, {-5.2, -11.2}}, color = {0, 127, 0}));
      connect(relPositionSensor.flange_a, prismatic.support) annotation(Line(visible = true, origin = {-11.6, 17.2}, points = {{1.6, 12.8}, {-8.4, 12.8}, {-8.4, -7.2}, {7.6, -7.2}, {7.6, -11.2}}, color = {0, 127, 0}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART LinearActuator -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>LinearActuator</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models an idealized linear actuator with a proportional controller.
</p><p class=\"\">
View the <a href=\"modelica://StewartPlatform.Components.LinearActuator#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND LinearActuator --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {0, 0, 255}, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100.0, -50.0}, {-30.0, 41.0}}), Rectangle(visible = true, lineColor = {0, 0, 255}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100.0, 40.0}, {-30.0, 50.0}}), Rectangle(visible = true, lineColor = {0, 0, 255}, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-30.0, -30.0}, {100.0, 20.0}}), Rectangle(visible = true, lineColor = {0, 0, 255}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-30.0, 20.0}, {100.0, 30.0}}), Line(visible = true, points = {{-30.0, -50.0}, {-30.0, 50.0}}), Text(visible = not useAxisFlange, origin = {-0.0, -5.0}, lineColor = {0, 0, 255}, extent = {{-150.0, 55.0}, {150.0, 115.0}}, textString = "%name", fontName = "Arial"), Polygon(visible = true, origin = {-0.0, -1.0}, lineColor = {0, 127, 0}, fillColor = {215, 215, 215}, fillPattern = FillPattern.Solid, points = {{90.0, 0.0}, {60.0, -30.0}, {60.0, -10.0}, {10.0, -10.0}, {10.0, 10.0}, {60.0, 10.0}, {60.0, 31.0}, {90.0, 0.0}}), Polygon(visible = true, origin = {-0.0, -1.0}, lineColor = {0, 127, 0}, fillColor = {215, 215, 215}, fillPattern = FillPattern.Solid, points = {{-90.0, 0.0}, {-60.0, 30.0}, {-60.0, 10.0}, {-10.0, 10.0}, {-10.0, -10.0}, {-60.0, -10.0}, {-60.0, -30.0}, {-90.0, 0.0}}), Text(visible = true, lineColor = {128, 128, 128}, extent = {{-95.0, -9.0}, {-60.0, 13.0}}, textString = "a", fontName = "Arial"), Text(visible = true, lineColor = {128, 128, 128}, extent = {{60.0, -13.0}, {96.0, 12.0}}, textString = "b", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end LinearActuator;

    model SixDOFLeg "Six-degree-of-freedom leg with controlled length"
      StewartPlatform.Components.LinearActuator leg(initialLength = initialLength, maxForce = maxForce, maxSpeed = maxSpeed, stateSelect = stateSelect, initialLengthFixed = initialLengthFixed, legDirection = legDirection) annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Joints.Spherical spherical(enforceStates = stateSelect == StateSelect.always, useQuaternions = false) annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Joints.Universal universal(stateSelect = stateSelect, n_b = {0, 0, 1}, phi_a.start = 0, phi_b.start = 0) annotation(Placement(visible = true, transformation(origin = {-40.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_b annotation(Placement(visible = true, transformation(origin = {148.4312, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {99.9537, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a annotation(Placement(visible = true, transformation(origin = {-148.4312, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0), iconTransformation(origin = {-99.9537, 0.0}, extent = {{-16.0, -16.0}, {16.0, 16.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput desiredLegLength annotation(Placement(visible = true, transformation(origin = {0.0, 110.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = -90), iconTransformation(origin = {0.0, 99.7857}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = -90)));
      parameter Modelica.SIunits.Length initialLength = 1;
      parameter Modelica.SIunits.Force maxForce = 500;
      parameter Modelica.SIunits.Velocity maxSpeed = 0.2;
      constant StateSelect stateSelect = StateSelect.prefer annotation(Dialog(tab = "Advanced"));
      Modelica.SIunits.Length length;
      parameter Real legDirection[3] = {0, 1, 0};
      parameter Boolean initialLengthFixed = false;
    equation
      connect(leg.frame_b, spherical.frame_a) annotation(Line(visible = true, origin = {20.05, 0}, points = {{-9.949, 0}, {9.95, 0}}, color = {95, 95, 95}));
      connect(spherical.frame_b, frame_b) annotation(Line(visible = true, origin = {99.216, 0}, points = {{-49.216, 0}, {49.216, 0}}, color = {95, 95, 95}));
      connect(frame_a, universal.frame_a) annotation(Line(visible = true, origin = {-99.216, 0}, points = {{-49.216, 0}, {49.216, 0}}, color = {95, 95, 95}));
      connect(universal.frame_b, leg.frame_a) annotation(Line(visible = true, origin = {-20.05, 0}, points = {{-9.95, 0}, {9.949, 0}}, color = {95, 95, 95}));
      connect(leg.realInput1, desiredLegLength) annotation(Line(visible = true, origin = {0, 60.04}, points = {{0, -49.96}, {0, 49.96}}, color = {0, 36, 164}));
      length = leg.prismatic.s;
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART SixDOFLeg -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>SixDOFLeg</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models a six-degree-of-freedom actuated leg with a length determined by a control signal.
</p><p class=\"\">
View the <a href=\"modelica://StewartPlatform.Components.SixDOFLeg#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND SixDOFLeg --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, origin = {-8.5714, -10.0}, lineColor = {0, 0, 255}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-71.4286, 40.0}, {-21.4286, 50.0}}), Rectangle(visible = true, origin = {-4.6154, 4.0}, lineColor = {0, 0, 255}, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-25.3846, -24.0}, {84.6154, 16.0}}), Rectangle(visible = true, origin = {-4.6154, 0.0}, lineColor = {0, 0, 255}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-25.3846, 20.0}, {84.6154, 30.0}}), Line(visible = true, points = {{-30.0, -38.3646}, {-30.0, 40.0}}), Text(visible = not useAxisFlange, origin = {-0.0, -15.0}, lineColor = {0, 0, 255}, extent = {{-150.0, 55.0}, {150.0, 115.0}}, textString = "%name", fontName = "Arial"), Rectangle(visible = true, origin = {-8.5714, -1.5385}, lineColor = {0, 0, 255}, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-71.4286, -38.4615}, {-21.4286, 31.5385}}), Ellipse(visible = true, origin = {-80.0, 0.0}, fillColor = {86, 86, 86}, fillPattern = FillPattern.Solid, extent = {{-20.0, -20.0}, {20.0, 20.0}}), Polygon(visible = true, lineColor = {0, 127, 0}, fillColor = {215, 215, 215}, fillPattern = FillPattern.Solid, points = {{-90.0, 0.0}, {-60.0, 30.0}, {-60.0, 10.0}, {-10.0, 10.0}, {-10.0, -10.0}, {-60.0, -10.0}, {-60.0, -30.0}, {-90.0, 0.0}}), Ellipse(visible = true, origin = {80.0, -0.0}, fillColor = {86, 86, 86}, fillPattern = FillPattern.Solid, extent = {{-20.0, -20.0}, {20.0, 20.0}}), Polygon(visible = true, lineColor = {0, 127, 0}, fillColor = {215, 215, 215}, fillPattern = FillPattern.Solid, points = {{90.0, 0.0}, {60.0, -30.0}, {60.0, -10.0}, {10.0, -10.0}, {10.0, 10.0}, {60.0, 10.0}, {60.0, 31.0}, {90.0, 0.0}}), Text(visible = true, origin = {-6.0, 3.0}, lineColor = {128, 128, 128}, extent = {{60.0, -13.0}, {96.0, 12.0}}, textString = "b", fontName = "Arial"), Text(visible = true, origin = {5.0, 1.3708}, lineColor = {128, 128, 128}, extent = {{-95.0, -9.0}, {-60.0, 13.0}}, textString = "a", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end SixDOFLeg;
    annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Components -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Stewart Platform: Components</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This subpackage contains components used in the <a href=\"modelica://StewartPlatform.StewartPlatformControlScenario\">main model</a>:
</p><ul><li><a href=\"modelica://StewartPlatform.Components.Base#diagram\">Base</a>: hexagonal fixed base of Stewart platform (<a href=\"modelica://StewartPlatform.Components.Base\">show documentation</a>)</li><li><a href=\"modelica://StewartPlatform.Components.LegOffsets#diagram\">LegOffsets</a>: block adding fixed leg length offsets (<a href=\"modelica://StewartPlatform.Components.LegOffsets\">show documentation</a>)</li><li><a href=\"modelica://StewartPlatform.Components.Legs#diagram\">Legs</a>: six actuated six-degree-of-freedom legs (<a href=\"modelica://StewartPlatform.Components.Legs\">show documentation</a>)</li><li><a href=\"modelica://StewartPlatform.Components.LinearActuator#diagram\">LinearActuator</a>: idealized linear actuator (<a href=\"modelica://StewartPlatform.Components.LinearActuator\">show documentation</a>)</li><li><a href=\"modelica://StewartPlatform.Components.Platform#diagram\">Platform</a>: hexagonal moveable surface of Stewart platform (<a href=\"modelica://StewartPlatform.Components.Platform\">show documentation</a>)</li><li><a href=\"modelica://StewartPlatform.Components.SixDOFLeg#diagram\">SixDOFLeg</a>: six-degree-of-freedom leg with controlled length (<a href=\"modelica://StewartPlatform.Components.SixDOFLeg\">show documentation</a>)</li></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Components --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {191, 191, 191}, fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25)}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
  end Components;

  model StewartPlatformControlScenario "Model of six-degree-of-freedom Stewart platform whose position is controlled by position setpoints."
    extends Modelica.Icons.Example;
    StewartPlatform.Components.Platform platform annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    StewartPlatform.Components.Base base annotation(Placement(visible = true, transformation(origin = {-40.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    StewartPlatform.Components.Legs legs annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Modelica.Blocks.Sources.CombiTimeTable legLengths(tableName = "LegLengths", fileName = Modelica.Utilities.Files.loadResource("modelica://StewartPlatform/DocumentationFiles/PlatformPath.txt"), tableOnFile = true, columns = 2:7) annotation(Placement(visible = true, transformation(origin = {-80.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    inner Modelica.Mechanics.MultiBody.World world(nominalLength = 0.1) annotation(Placement(visible = true, transformation(origin = {40.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    StewartPlatform.Components.LegOffsets legOffsets(leg1Offset = 0) annotation(Placement(visible = true, transformation(origin = {-40.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
  equation
    connect(legOffsets.offsetLegLengths[:], legs.desiredLegLengths[:]) annotation(Line(visible = true, origin = {-10, 29.991}, points = {{-19, 10.009}, {10, 10.009}, {10, -17.991}}, color = {1, 37, 163}));
    connect(legLengths.y[:], legOffsets.desiredLegLengths[:]) annotation(Line(visible = true, origin = {-59.5, 40}, points = {{-9.5, 0}, {7.5, 0}}, color = {1, 37, 163}));
    connect(legs.frame_b[:], platform.frame_b[:]) annotation(Line(visible = true, origin = {20.009, 0}, points = {{-10.014, 0}, {10.014, 0}}, color = {95, 95, 95}));
    connect(base.frame_b[:], legs.frame_a[:]) annotation(Line(visible = true, origin = {-20.009, 0}, points = {{-10.032, 0}, {10.032, 0}}, color = {95, 95, 95}));
    annotation(__Wolfram(PlotSet(plots = {Plot(name = "LegLengths", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = legs.leg1.length, legend = "Leg 1"), Curve(x = time, y = legs.leg2.length, legend = "Leg 2"), Curve(x = time, y = legs.leg3.length, legend = "Leg 3"), Curve(x = time, y = legs.leg4.length, legend = "Leg 4"), Curve(x = time, y = legs.leg5.length, legend = "Leg 5"), Curve(x = time, y = legs.leg6.length, legend = "Leg 6")})}), Plot(name = "Leg1", group = "LegLengthVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = legs.leg1.length, legend = "Length"), Curve(x = time, y = legs.leg1.desiredLegLength, legend = "Reference")})}), Plot(name = "Leg2", group = "LegLengthVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = legs.leg2.length, legend = "Length"), Curve(x = time, y = legs.leg2.desiredLegLength, legend = "Reference")})}), Plot(name = "Leg3", group = "LegLengthVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = legs.leg3.length, legend = "Length"), Curve(x = time, y = legs.leg3.desiredLegLength, legend = "Reference")})}), Plot(name = "Leg4", group = "LegLengthVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = legs.leg4.length), Curve(x = time, y = legs.leg4.desiredLegLength)})}), Plot(name = "Leg5", group = "LegLengthVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = legs.leg5.length, legend = "Length"), Curve(x = time, y = legs.leg5.desiredLegLength, legend = "Reference")})}), Plot(name = "Leg6", group = "LegLengthVsReference", subPlots = {SubPlot(curves = {Curve(x = time, y = legs.leg6.length, legend = "Length"), Curve(x = time, y = legs.leg6.desiredLegLength, legend = "Reference")})})})), Documentation(info = "<html><!--WSMINSERTIONTAGSTART ExampleModel -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Stewart Platform: Design & Analyze Parallel Manipulator</h1><div class=\"contenttable\">
   <span class=\"contenttableheader\">CONTENTS:</span><br/>
   <table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Simulation&Animation').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Simulation & Animation</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Design:3DGeometry').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Design: 3D Geometry</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Visualization:Custom3DAnimation').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Visualization: Custom 3D Animation</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Visualization:LegLengthOffset').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Visualization: Leg Length Offset</a></td><td></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
This model simulates a six-degree-of-freedom Stewart platform. The position and orientation of the platform is determined by the lengths of six legs. Each leg comprises a linear actuator and five rotational degrees of freedom. The model is constructed from components in the <a href=\"modelica://Modelica.Mechanics\">Modelica.Mechanics</a> library. The Wolfram Language is used to plan the 3D geometry of the model, and to produce custom visualizations of simulation results.
</p><p class=\"\">
View the <a href=\"modelica://StewartPlatform.StewartPlatformControlScenario#diagram\">model diagram</a> for this model.
</p><p class=\"\">
In order to get the full experience of this example, you need the following:
</p><ul><li>A desktop Wolfram Language product; a free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></li><li>The <a href=\"StewartPlatform.nb\">StewartPlatform.nb</a> notebook that came in the same bundle as this model</li></ul><div class=\"mathematicapointerwrapper\">
   <div class=\"mathematicapointertop\">&nbsp;</div>
   <div class=\"mathematicapointerdiv\"><p class=\"mathematicapointer\">
These pages show an overview of the example. For the full example, open the accompanying notebook <a href=\"StewartPlatform.nb\">StewartPlatform.nb</a>.
</p></div>
   </div><a id=\"headerTag_Simulation&Animation\" class=\"target\">&nbsp;</a>
    <h2>Simulation & Animation</h2>
    <p class=\"\">
To simulate the model and view a 3D animation of it, follow the steps below:
</p><ul><li>Click the <img src=\"modelica://StewartPlatform/DocumentationFiles/simCenter.png\" alt=\"simCenter\"/> button in the top-right corner.</li><li>When the build is finished, click the <span class=\"dialogelement\">Simulate</span> button <img src=\"modelica://StewartPlatform/DocumentationFiles/simulate.png\" alt=\"simulate\"/>.</li><li>When the simulation is finished, click the <span class=\"dialogelement\">Animate</span> button <img src=\"modelica://StewartPlatform/DocumentationFiles/animate.png\" alt=\"animate\"/>.</li><li>Use your mouse or trackpad to drag the animation into a good angle, and zoom in with your scroll wheel or by using the trackpad. Then click the play button to play the animation.</li></ul><p class=\"\">
The automatically generated animation shows the Stewart platform following a prescribed test trajectory:
</p><p class=\"\">
<img src=\"modelica://StewartPlatform/DocumentationFiles/animation.png\" alt=\"animation\"/>
</p><p class=\"\">
See below for more advanced custom visualizations.
</p><a id=\"headerTag_Design:3DGeometry\" class=\"target\">&nbsp;</a>
    <h2>Design: 3D Geometry</h2>
    <p class=\"\">
Use the Wolfram Language to plan the 3D geometry of the Stewart platform and solve the inverse kinematics problem to plan the motion of the platform:
</p><p class=\"\">
<img src=\"modelica://StewartPlatform/DocumentationFiles/design3DGeometry.png\" alt=\"design3DGeometry\"/>
</p><a id=\"headerTag_Visualization:Custom3DAnimation\" class=\"target\">&nbsp;</a>
    <h2>Visualization: Custom 3D Animation</h2>
    <p class=\"\">
Build up a custom 3D visualization of the Stewart platform using the Wolfram Language and export an AVI movie:
</p><p class=\"\">
<img src=\"modelica://StewartPlatform/DocumentationFiles/visualizationCustom3DAnimation.png\" alt=\"visualizationCustom3DAnimation\"/>
</p><a id=\"headerTag_Visualization:LegLengthOffset\" class=\"target\">&nbsp;</a>
    <h2>Visualization: Leg Length Offset</h2>
    <p class=\"\">
Use the Wolfram Language to create a custom visualization of the effect of a small offset in a single leg:
</p><p class=\"\">
<img src=\"modelica://StewartPlatform/DocumentationFiles/visualizationCustomOffset.png\" alt=\"visualizationCustomOffset\"/>
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND ExampleModel --></html>", revisions = ""), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-120.0, -40.0}, {80.0, 80.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), experiment(StartTime = 0.0, StopTime = 20));
  end StewartPlatformControlScenario;
  annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART StewartPlatformPackage -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Stewart Platform: Design & Analyze Parallel Manipulator</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This package contains a model of a six-degree-of-freedom Stewart platform, as well as a component library used in the model.
</p><ul><li><a href=\"modelica://StewartPlatform.StewartPlatformControlScenario#diagram\">StewartPlatformControlScenario</a>: six-degree-of-freedom Stewart platform following prescribed trajectory (<a href=\"modelica://StewartPlatform.StewartPlatformControlScenario\">show documentation</a>)</li><li><a href=\"modelica://StewartPlatform.Components#info\">Components</a>: library with custom components for the Stewart platform</li></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND StewartPlatformPackage --></html>", revisions = ""), preferredView = "info", uses(Modelica(version = "3.2.3")), __Wolfram(openClass = StewartPlatform.StewartPlatformControlScenario, useDocumentationTemplate = false), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
end StewartPlatform;